# Copyright 2018 eShares, Inc. dba Carta, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed
# under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
# CONDITIONS OF ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.

from .cached import CachedFeatureFlagStore
from .consul import ConsulFeatureFlagStore
from .memory import MemoryFeatureFlagStore
from .postgresql import PostgreSQLFeatureFlagStore
from .redis import RedisFeatureFlagStore
from .replicated import ReplicatedFeatureFlagStore
from .s3 import S3FeatureFlagStore
from .thrift import ThriftRPCFeatureFlagStore

__all__ = [
    "CachedFeatureFlagStore",
    "ConsulFeatureFlagStore",
    "MemoryFeatureFlagStore",
    "PostgreSQLFeatureFlagStore",
    "RedisFeatureFlagStore",
    "ReplicatedFeatureFlagStore",
    "S3FeatureFlagStore",
    "ThriftRPCFeatureFlagStore",
]
